@@ -1,4 +1,6 @@
+from __future__ import print_function
 from .unit import Unit
+from .util import convert_to_ul, quad_ind_to_num
 import sys
 
 if sys.version_info[0] >= 3:
@@ -36,6 +38,7 @@ class Well(object):
         self.container = container
         self.index = index
         self.volume = None
+        self.name = None
         self.properties = {}
 
     def set_properties(self, properties):
@@ -82,13 +85,28 @@ class Well(object):
             Theoretical volume to indicate for a Well.
 
         """
-        if Unit.fromstring(vol) > Unit(
+        v = convert_to_ul(vol)
+        if v > Unit(
                 self.container.container_type.well_volume_ul, "microliter"):
             raise ValueError("Theoretical volume you are trying to set "
                              "exceeds the maximum volume of this well.")
-        self.volume = Unit.fromstring(vol)
+        self.volume = v
         return self
 
+    def set_name(self, name):
+        """
+        Set a name for this well for it to be included in a protocol's "outs" section
+
+        Parameters
+        ----------
+        name : str
+            Well name.
+
+        """
+        self.name = name
+        return self
+
+
     def humanize(self):
         """
         Return the human readable representation of the integer well index
@@ -191,6 +209,21 @@ class WellGroup(object):
         else:
             return self.wells.append(other)
 
+    def extend(self, other):
+        """
+        Extend this WellGroup with another WellGroup.
+
+        Parameters
+        ----------
+        other : WellGroup
+            WellGroup to extend this WellGroup.
+
+        """
+        if not isinstance(other, WellGroup):
+            raise TypeError("Input given is not of type 'WellGroup'.")
+        else:
+            return self.wells.extend(other.wells)
+
     def __getitem__(self, key):
         """
         Return a specific Well from a WellGroup.
@@ -260,10 +293,11 @@ class Container(object):
 
     """
 
-    def __init__(self, name, id, container_type):
+    def __init__(self, id, container_type, name=None, storage=None):
         self.name = name
         self.id = id
         self.container_type = container_type
+        self.storage = storage
         self._wells = [Well(self, idx)
                        for idx in xrange(container_type.well_count)]
 
@@ -296,14 +330,21 @@ class Container(object):
             integer or a string.
 
         """
-        if not isinstance(i, (basestring, int, list)):
-            raise TypeError("Well reference given is not of type 'int', 'str'"
-                            "or 'list'.")
-
         if isinstance(args[0], list):
-            args = args[0]
+            wells = args[0]
+        else:
+            wells = [args[0]]
+        for a in args[1:]:
+            if isinstance(a, list):
+                wells.extend(a)
+            else:
+                wells.extend([a])
+        for w in wells:
+            if not isinstance(w, (basestring, int, list)):
+                raise TypeError("Well reference given is not of type"
+                                " 'int', 'str' or 'list'.")
 
-        return WellGroup([self.well(i) for i in args])
+        return WellGroup([self.well(w) for w in wells])
 
     def robotize(self, well_ref):
         """
@@ -314,6 +355,9 @@ class Container(object):
         `ContainerType.robotize()`_ for more information.
 
         """
+        if not isinstance(well_ref, (basestring, int, Well)):
+            raise TypeError("Well reference given is not of type 'str' \
+                            'int', or 'Well'.")
         return self.container_type.robotize(well_ref)
 
     def humanize(self, well_ref):
@@ -324,8 +368,9 @@ class Container(object):
         Uses the humanize function from the ContainerType class. Refer to
         `ContainerType.humanize()`_ for more information.
 
-
         """
+        if not isinstance(well_ref, int):
+            raise TypeError("Well reference given is not of type 'int'.")
         return self.container_type.humanize(well_ref)
 
     def decompose(self, well_ref):
@@ -337,6 +382,9 @@ class Container(object):
         `ContainerType.decompose()`_ for more information.
 
         """
+        if not isinstance(well_ref, (int, basestring, Well)):
+            raise TypeError("Well reference given is not of type 'int', \
+                            'str' or Well.")
         return self.container_type.decompose(well_ref)
 
     def all_wells(self, columnwise=False):
@@ -434,10 +482,16 @@ class Container(object):
 
         """
         # TODO(Define what each quadrant number corresponds toL)
-        if not isinstance(quad, int):
-            raise TypeError("Quadrant given is not of type 'int'.")
-        assert self.container_type.well_count == 384
-        assert quad in [0, 1, 2, 3], "Quadrant number must be between 0 and 3."
+        if isinstance(quad, str):
+            quad = quad_ind_to_num(quad)
+        if self.container_type.well_count == 96:
+            if quad == 0:
+                return self._wells
+            else:
+                raise RuntimeError("0 or 'A1' is the only valid quadrant for a 96-well plate.")
+        elif self.container_type.well_count < 96:
+            raise RuntimeError("Cannot return quadrant for a container type with less than 96 wells.")
+        assert quad in [0, 1, 2, 3], "Invalid quadrant entered for the specified plate type."
 
         start_well = [0, 1, 24, 25]
         wells = []
