@@ -184,7 +184,7 @@ class ContainerType(namedtuple("ContainerType",
             well_ref.
 
         """
-        if not isinstance(idx, (int, basestring)):
+        if not isinstance(idx, (int, basestring, Well)):
             raise TypeError("Well index given is not of type 'int' or \
                             'str'.")
         idx = self.robotize(idx)
@@ -206,8 +206,7 @@ _CONTAINER_TYPES = {
                               well_coating=None,
                               sterile=False,
                               is_tube=False,
-                              capabilities=["spin", "incubate", "absorbance",
-                                            "fluorescence", "luminescence"],
+                              capabilities=[],
                               shortname="384-flat",
                               col_count=24,
                               dead_volume_ul=12),
@@ -218,10 +217,21 @@ _CONTAINER_TYPES = {
                              well_coating=None,
                              sterile=None,
                              is_tube=False,
-                             capabilities=["thermocycle", "spin", "incubate"],
+                             capabilities=[],
                              shortname="384-pcr",
                              col_count=24,
                              dead_volume_ul=8),
+    "384-echo": ContainerType(name="384-well Echo plate",
+                              well_count=384,
+                              well_depth_mm=None,
+                              well_volume_ul=65.0,
+                              well_coating=None,
+                              sterile=None,
+                              is_tube=False,
+                              capabilities=[],
+                              shortname="384-echo",
+                              col_count=24,
+                              dead_volume_ul=5),
     "96-flat": ContainerType(name="96-well flat-bottom plate",
                              well_count=96,
                              well_depth_mm=None,
@@ -229,9 +239,7 @@ _CONTAINER_TYPES = {
                              well_coating=None,
                              sterile=False,
                              is_tube=False,
-                             capabilities=["spin", "incubate", "absorbance",
-                                           "fluorescence", "luminescence",
-                                           "gel_separate", "sangerseq"],
+                             capabilities=[],
                              shortname="96-flat",
                              col_count=12,
                              dead_volume_ul=25),
@@ -243,9 +251,7 @@ _CONTAINER_TYPES = {
                                 well_coating=None,
                                 sterile=False,
                                 is_tube=False,
-                                capabilities=["spin", "incubate", "absorbance",
-                                              "fluorescence", "luminescence",
-                                              "gel_separate", "sangerseq"],
+                                capabilities=[],
                                 shortname="96-flat-uv",
                                 col_count=12,
                                 dead_volume_ul=25),
@@ -256,8 +262,7 @@ _CONTAINER_TYPES = {
                             well_coating=None,
                             sterile=None,
                             is_tube=False,
-                            capabilities=["thermocycle", "spin", "incubate",
-                                          "sanger_sequence", "gel_separate"],
+                            capabilities=[],
                             shortname="96-pcr",
                             col_count=12,
                             dead_volume_ul=15),
@@ -267,20 +272,29 @@ _CONTAINER_TYPES = {
                              well_volume_ul=2000.0,
                              well_coating=None,
                              sterile=False,
-                             capabilities=["incubate", "pipette", "sangerseq",
-                                           "spin", "gel_separate"],
+                             capabilities=[],
                              shortname="96-deep",
                              is_tube=False,
                              col_count=12,
                              dead_volume_ul=15),
+    "24-deep": ContainerType(name="24-well extended capacity plate",
+                             well_count=24,
+                             well_depth_mm=None,
+                             well_volume_ul=10000.0,
+                             well_coating=None,
+                             sterile=False,
+                             capabilities=[],
+                             shortname="24-deep",
+                             is_tube=False,
+                             col_count=6,
+                             dead_volume_ul=15),
     "micro-2.0": ContainerType(name="2mL Microcentrifuge tube",
                                well_count=1,
                                well_depth_mm=None,
                                well_volume_ul=2000.0,
                                well_coating=None,
                                sterile=False,
-                               capabilities=["spin", "incubate", "pipette",
-                                             "sangerseq", "gel_separate"],
+                               capabilities=[],
                                shortname="micro-2.0",
                                is_tube=True,
                                col_count=1,
@@ -291,8 +305,7 @@ _CONTAINER_TYPES = {
                                well_volume_ul=1500.0,
                                well_coating=None,
                                sterile=False,
-                               capabilities=["spin", "incubate", "pipette",
-                                             "sangerseq", "gel_separate"],
+                               capabilities=[],
                                shortname="micro-1.5",
                                is_tube=True,
                                col_count=1,
