@@ -1,4 +1,6 @@
 import json
+from .pipette_tools import assign
+
 
 '''
     :copyright: 2015 by The Autoprotocol Development Team, see AUTHORS
@@ -79,12 +81,49 @@ class Dispense(Instruction):
         [{"column": <column num>, "volume": <volume>}, ...]
 
     """
-    def __init__(self, ref, reagent, columns):
-        super(Dispense, self).__init__({
-            "op": "dispense",
-            "object": ref,
-            "reagent": reagent,
-            "columns": columns
+    def __init__(self, ref, reagent, columns, speed):
+        disp = {
+                "op": "dispense",
+                "object": ref,
+                "reagent": reagent,
+                "columns": columns
+        }
+        assign(disp, "x_speed_percentage", speed)
+
+        super(Dispense, self).__init__(disp)
+
+class AcousticTransfer(Instruction):
+    """
+    Specify source and destination wells for transfering liquid via an acoustic
+    liquid handler.  Droplet size is usually device-specific.
+
+    Parameters
+    ----------
+    groups : list(dict)
+        List of `transfer` groups in the form of:
+
+        .. code-block:: json
+
+        {
+            "transfer": [
+                {
+                    "to": well,
+                    "from": well,
+                    "volume": volume
+                }
+            ]
+        }
+
+    droplet_size : str, Unit
+        Volume representing a droplet_size.  The volume of each transfer should
+        be a multiple of this volume.
+
+    """
+    def __init__(self, transfers, droplet_size):
+        super(AcousticTransfer, self).__init__({
+            "op": "acoustic_transfer",
+            "groups": [{"transfer": transfers}],
+            "droplet_size": droplet_size
         })
 
 class Spin(Instruction):
@@ -274,7 +313,7 @@ class Incubate(Instruction):
         temperature
 
     """
-    WHERE = ["ambient", "warm_37", "cold_4", "cold_20", "cold_80"]
+    WHERE = ["ambient", "warm_30", "warm_37", "cold_4", "cold_20", "cold_80"]
 
     def __init__(self, ref, where, duration, shaking=False, co2=0):
         if where not in self.WHERE:
@@ -309,13 +348,17 @@ class SangerSeq(Instruction):
       Name of sequencing dataset that will be returned.
 
     """
-    def __init__(self, obj, wells, dataref):
-        super(SangerSeq, self).__init__({
+    def __init__(self, obj, wells, dataref, type, primer):
+        seq = {
             "op": "sanger_sequence",
+            "type": type,
             "object": obj,
             "wells": wells,
             "dataref": dataref
-        })
+        }
+        if primer and type == "rca":
+            seq["primer"] = primer
+        super(SangerSeq, self).__init__(seq)
 
 
 class GelSeparate(Instruction):
@@ -731,13 +774,18 @@ class Autopick(Instruction):
         autopicking
 
     """
-    def __init__(self, source, dests, min_count=1):
-        super(Autopick, self).__init__({
+    def __init__(self, source, dests, min_count, criteria, dataref):
+        pick = {
             "op": "autopick",
             "from": source,
             "to": dests,
-            "min_colony_count": min_count
-        })
+            "min_colony_count": min_count,
+            "dataref": dataref
+        }
+        if criteria:
+            pick["criteria"] = criteria
+
+        super(Autopick, self).__init__(pick)
 
 class ImagePlate(Instruction):
     """
@@ -763,9 +811,9 @@ class ImagePlate(Instruction):
 
 class Provision(Instruction):
     """
-    A generic instruction for provisioning a commercial resource from a
-    catalog and defining destination well(s).  A new tip is used for each
-    destination well specified.
+    Provision a commercial resource from a catalog into the specified
+    destination well(s).  A new tip is used for each destination well
+    specified to avoid contamination.
 
     Parameters
     ----------
@@ -797,3 +845,43 @@ class Provision(Instruction):
             "resource_id": resource_id,
             "to": dests
             })
+
+class FlashFreeze(Instruction):
+    """
+    Flash freeze the contents of the specified container by submerging it in
+    liquid nitrogen for the specified amount of time.
+
+    Parameters
+    ----------
+    container : Container, str
+        Container to be flash frozen.
+    duration : str, Unit
+        Duration to submerge specified container in liquid nitrogen.
+
+    """
+
+    def __init__(self, container, duration):
+        super(FlashFreeze, self).__init__({
+            "op": "flash_freeze",
+            "object": container,
+            "duration": duration
+        })
+
+class Stamp(Instruction):
+    """
+    A stamp instruction is constructed as a list of groups, executed in order,
+    where each group is a transfer. The same disposable tips, shape and
+    tip_layout will be used within a transfer group.
+
+    transfer:
+
+        For each element in the transfer list, in order, aspirates the specifed
+        volume from the source well and dispenses the same volume into the
+        target well.
+    """
+
+    def __init__(self, groups):
+        super(Stamp, self).__init__({
+            "op": "stamp",
+            "groups": groups
+         })
