@@ -9,6 +9,7 @@ import sys
 
 '''
 
+
 class Unit(object):
     """A representation of a measure of volume, duration, temperature, or
     concentration.
@@ -51,6 +52,9 @@ class Unit(object):
     def __str__(self):
         return ":".join([str(self.value), self.unit])
 
+    def __repr__(self):
+        return "Unit(%s, %s)" % (self.value, self.unit)
+
     def _check_type(self, other):
         if not isinstance(other, Unit):
             raise ValueError("Both operands must be of type Unit")
@@ -72,7 +76,15 @@ class Unit(object):
     def __le__(self, other):
         self._check_type(other)
         return self.value <= other.value
+        
+    def __gt__(self, other):
+        self._check_type(other)
+        return self.value > other.value
 
+    def __ge__(self, other):
+        self._check_type(other)
+        return self.value >= other.value
+        
     def __eq__(self, other):
         self._check_type(other)
         return self.value == other.value
@@ -89,6 +101,8 @@ class Unit(object):
             other = other.value
         return Unit(self.value * other, self.unit)
 
+    __rmul__ = __mul__
+
     def __div__(self, other):
         if isinstance(other, Unit):
             print("WARNING: Unit.__mul__ and __div__ only support scalar "
